@@ -1,3 +1,5 @@
+use std::time::Duration;
+
 use crate::{
     glottis::Glottis, noise::NoiseSource, tract::Tract, tract_shaper::TractShaper,
     turbulence::TurbulencePoint,
@@ -31,6 +33,11 @@ impl PinkTrombone {
         self.sample_rate
     }
 
+    /// How much time has already been generated.
+    pub fn time(&self) -> Duration {
+        Duration::from_secs_f32(self.tract().time)
+    }
+
     // /// -1..+1
     //pub fn noise(self) -> f32 {}
 
@@ -105,6 +112,10 @@ impl PinkTrombone {
         self.glottis_mut().auto_wobble = vibrato_wobble
     }
 
+    pub fn set_velum_open(&mut self, velum_open: bool) {
+        self.shaper.set_velum_open(velum_open);
+    }
+
     pub fn turbulence_points(&mut self) -> &mut Vec<TurbulencePoint> {
         &mut self.tract_mut().turbulence_points
     }
